@@ -1654,7 +1654,7 @@ f = io.open(pattname, "w")
 if f then
     f:write(
 [[
-[M2] (golly 3.0)
+[M2] (golly 3.3)
 #R RainbowASOv1.3
 #C Spaceships of all unit-fraction speeds from c/1 to c/50,
 #C  with a scattering of slower speeds down to c/150.
@@ -1662,9 +1662,12 @@ if f then
 #C  of other Life-like and isotropic non-totalistic rules.
 #C  The RainbowASOv1.3 "mashup rule" lets spaceships from 
 #C  different rules run simultaneously in the same pattern.
-#C Rule created and pattern compiled by muzik,
-#C  with hyperbolic spaceship stunt-flying arrangement by Adam P. Goucher.
-#C http://www.conwaylife.com/forums/viewtopic.php?f=11&t=2899&p=46271#p46271
+#C Rule created and pattern compiled by muzik, 9 July 2017, with 
+#C  hyperbolic spaceship stunt-flying arrangement by Adam P. Goucher.
+#C http://www.conwaylife.com/forums/viewtopic.php?p=46271#p46271
+#C A more recent version of the RainbowASO rule, also by muzik,
+#C  can be found here (RainbowASOv3.1, 6 July 2018):
+#C http://www.conwaylife.com/forums/viewtopic.php?p=61655#p61655
 1 0 0 0 35
 2 0 1 0 0
 1 35 0 0 35
